# pages/Links.py
import streamlit as st

st.title("Links")
st.write("Here are some links to my online profiles and website:")

# Social Media and Professional Links
st.markdown("[GitHub](https://github.com/yourusername)")
st.markdown("[LinkedIn](https://linkedin.com/in/yourusername)")
st.markdown("[Personal Website](https://yourwebsite.com)")

    # Add more links as needed
